test-basic
==========


.. world:character:: Gardakan
    Lord Gardakan
    Gardy

    A mighty paladin from :world:loc:`Québec City`


.. world:location:: Québec City

    L'accent d'Amérique!

    This is where :world:npc:`Gardy` lives!


.. rule:skill:: coding

    Makes you write code.
